/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "finalpage.h"
#include "xmlparamexport.h"

FinalPage::FinalPage( QWidget *parent )
  : QWizardPage( parent )
{
  setTitle( "Export" );
  subtitle = new QLabel( "Specify the directory for the Export File." );
  line = new QLineEdit();
  line->resize( 200, 30 );
  button = new QPushButton( "Browse..." );
  button->resize( 50, 30 );
  text2 = new QLabel( "Click \"Next\" to save the parameters in the Export File." );
  layout = new QGridLayout();
  layout->addWidget( subtitle, 0, 0, 1, 2 );
  layout->addWidget( line, 1, 0, 1, 1 );
  layout->addWidget( button, 1, 1, 1, 1 );
  layout->addWidget( text2, 2, 0, 1, 2 );
  setLayout( layout );
  connect( button, SIGNAL( clicked() ), this, SLOT( getOutFileName() ) );
  connect( line, SIGNAL( textChanged( QString ) ), this, SLOT( checkOutFileName() ) );
}

FinalPage::~FinalPage() {}

QString FinalPage::getText()
{
  return line->text();
}

void FinalPage::getOutFileName()
{
  XMLParamExport::setCurrentDirectory();
  QFileDialog saveDialog( this, tr( "Save current settings" ), "./", tr( "XML files (*.xml)" ) );
  saveDialog.setFileMode( QFileDialog::AnyFile );
  saveDialog.setDefaultSuffix( "xml" );
  saveDialog.setAcceptMode( QFileDialog::AcceptSave );
  saveDialog.setViewMode( QFileDialog::Detail );

  if ( saveDialog.exec() ) {
    line->setText( saveDialog.selectedFiles().at( 0 ) );
  }
}

void FinalPage::checkOutFileName()
{
  QString outFileName = line->text();
  bool fileNameOk;
  emit paramFileNameSaveChanged( outFileName, fileNameOk );
  emit outFileNameIsOK( fileNameOk );
}
