/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/



#ifndef FINALPAGE_H
#define FINALPAGE_H

#include <QtWidgets>


/**
 * The FinalPage exports the XML-File with the choosen settings. The user can specify
 * the directory and file name for saving the parameters by either typing them
 * directly into the text line, or he can browse the file system using the
 * browse button. The FinalPage checks the user input automatically. The finish
 * button of the OpenGPIWizard is only activated, if a valid directory is specified.
 */
class FinalPage : public QWizardPage {
  Q_OBJECT

public:
  /// Constructs a FinalPage with a text line, a browse button and some explaining text.
  FinalPage( QWidget *parent );
  /// The destructor.
  ~FinalPage();
  ///  \returns the text of the text line.
  QString getText();
public slots:
  /** Checks the text in the text line using the slot XMLParamImport::checkParamFileNameSave(QString,bool &).
   *  If it represents a valid directory, the signal outFileNameIsOK(true) is emitted,
   *  otherwise the signal outFileNameIsOK(false) is emitted.
   */
  void checkOutFileName();
signals:
  void paramFileNameSaveChanged( QString, bool & );
  /// This signal is emitted whenever the text in the text line changes (by user or by program).
  /// It passes true, if the text represents a valid parameter file name, otherwise it passes false.
  void outFileNameIsOK( bool );
  void showDialog();
private:
  QLabel *subtitle, *text2;
  QLineEdit *line;
  QPushButton *button;
  QGridLayout *layout;
private slots:
  void getOutFileName();
};

#endif
