/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2015 Nikita Bogutzki, Albert Mink
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "keydelegate.h"
#include "keyinput.h"
#include <QSpinBox>

KeyDelegate::KeyDelegate( QObject *parent ) : QStyledItemDelegate( parent )
{ }

QWidget *KeyDelegate::createEditor( QWidget *parent,
                                    const QStyleOptionViewItem &/*option*/, const QModelIndex &index ) const
{
  KeyInput *editor = new KeyInput( parent, index.data( Qt::EditRole ), index );
  connect( editor, SIGNAL( showMyInfo( QString, QString ) ),
           this, SIGNAL( setInfoD( QString, QString ) ) );
  emit editor->showMyInfo( editor->getBoxTitle(), editor->getMyInfo() );
  connect( editor, SIGNAL( editingFinished() ), this, SLOT( commitAndCloseEditor() ) );
  return editor;
}

QSize KeyDelegate::sizeHint( const QStyleOptionViewItem &option,
                             const QModelIndex &index ) const
{
  QSize size = QStyledItemDelegate::sizeHint( option, index );
  size.setHeight( 70 );
  return size;
}

void KeyDelegate::commitAndCloseEditor()
{
  KeyInput *editor = qobject_cast<KeyInput *>( sender() );
  emit commitData( editor );
  emit closeEditor( editor, NoHint );
}

void KeyDelegate::setEditorData( QWidget *editor, const QModelIndex &index ) const
{
  qDebug() << "setEditorData()";
  static_cast<KeyInput *>( editor )->changeData( index.data( Qt::EditRole ) );
}

void KeyDelegate::setModelData( QWidget *editor, QAbstractItemModel *model,
                                const QModelIndex &index ) const
{
  model->setData( index, static_cast<KeyInput *>( editor )->value() );
}
