/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2015 Nikita Bogutzki, Albert Mink
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#ifndef KEYDELEGATE_H
#define KEYDELEGATE_H

#include <QStyledItemDelegate>

/** KeyDelegate sets the editor for delegating the KeyInputs into the ListView of the Keypage. If a KeyInput is clicked, an editor is created where the user can change the key values. When the user is finished, the edited value is saved and the editor will be closed.
*/
class KeyDelegate : public QStyledItemDelegate {
  Q_OBJECT

public:
  explicit KeyDelegate( QObject *parent = NULL );
  // creates KeyInput
  QWidget *createEditor( QWidget *parent, const QStyleOptionViewItem &option,
                         const QModelIndex &index ) const;
  QSize sizeHint( const QStyleOptionViewItem &option, const QModelIndex &index ) const;
  /// Copy data from KeyPage to the editor
  void setEditorData( QWidget *editor, const QModelIndex &index ) const;
  /// Stores the edited data value in the model
  void setModelData( QWidget *editor, QAbstractItemModel *model, const QModelIndex &index ) const;
signals:
  /// The signal includes the title and the info of the given key. 
  /// These infos will be shown in the infobox of the Keypage by creating a connect in the KeyPage.
  void setInfoD( QString, QString );

private slots:
  /// Is necessary for saving the edited value of the key and for closing the editor of the key (KeyInput) in general.
  void commitAndCloseEditor();
};

#endif 
