/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/



#ifndef KEYINPUT_H
#define KEYINPUT_H

#include <QtWidgets>


/** KeyInput offers graphical objects as input elements for the parameters.
 * A KeyInput is presented as a box with fixed size (width 400 pixels, height 70 pixels), which contains the input element.
 * The input element can either be a text line, a drop-down-menu or an integer spinbox.
 * The keyname appears as the title of the box.
 */
class KeyInput : public QWidget {
private:
  Q_OBJECT

signals:
  /** This signal is emitted, when the user points with the mouse inside the
   * KeyInput widget. It passes the keyname as first argument, and the keyinfo
   * as second argument.
   */
  void showMyInfo( QString, QString );
  void editingFinished();
public:

  /**
  * Constructs and initializes a KeyInput.
  * \param parent The parent widget.
  * \param data   Contains the data used to initialize the KeyInput.
  * \param index  Refers to the Key in the TreeModel this KeyInput belongs to.
   */
  KeyInput( QWidget *parent, QVariant data, QModelIndex index );
  /// Constructs an empty (uninitialized) KeyInput.
  KeyInput( QWidget *parent );
  /// Dtor
  ~KeyInput();
  /// Returns the current value of the input element as a QVariant.
  QVariant value();
  /// Returns the index corresponding to the key.
  QModelIndex index();

  void changeData( QVariant v );

  bool showThis;

  const QString getBoxTitle();
  const QString getMyInfo();

private:

  QLineEdit *lineEdit;    /**< is a possible element placed in the box*/
  QGroupBox *box;
  QComboBox *comboBox;    /**< is a possible element placed in the box*/
  QSpinBox *spinBox;      /**< is a possible element placed in the box*/
  QCheckBox *checkBox;    /**< is a possible element placed in the box*/

  QString myInfo;         /**< string to display as a help message*/
  QModelIndex myIndex;    /**< position/reference to item/(data-)Leaf in TreeModel*/
  QPushButton *browseButton;  /**< */
  int t;                  /** 0-QLineEdit 1-QComboBox,2-QSpinBox*/

  /// this map represents the xml element <key>
  QMap<QString, QVariant> map;

  void setAccess();
  void setWhite();
  void setRed();

private slots:
  void browseButtonClicked();

};


#endif
