/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka, Nikita Bogutzki
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/





#ifndef KEYPAGE_H
#define KEYPAGE_H

#include "keyinput.h"
#include <QTreeView>
#include <QListView>
#include "datamodel.h"
#include "keydelegate.h"


/** The KeyPage holds several KeyInput objects and an InfoBox and presents them in a vertical layout.
 * It provides scrollbars, if not all of the KeyInput objects can be displayed at once.
 */
class KeyPage : public QWizardPage {
  Q_OBJECT

public:
  /// Constructs an empty KeyPage which only contains the InfoBox.
  KeyPage( QWidget *parent );
  /// The distructor
  ~KeyPage();
  void selectNext();
  void selectPrevious();
  DataModel *dataModel;
  KeyDelegate *keyDelegatePage;
  QListView *listView;
public slots:
  /// The slot which interprets the number invalid keys of the datamodel and emits the signal "invalidKeysChangedKeyPage(bool)" with the "false" for invalidkeys > 0, otherwise "true"
  void invalidKeysChangedBool( int invalidKeysKeyPage );
  /**
   * This slot is used to present help information in the InfoBox.
   * \param title This string is set as the title in the InfoBox.
   * \param text The info text.
   */
  void setInfo( QString title, QString text );
  /**
   * This slot is used to present warnings in the InfoBox.
   * \param warning The warning text.
   */
  void setInfo( QString warning );
  /**
   * This slot receives either a ListModel, a TreeModel or a DataModel.
   */
  void receiveModel( QAbstractItemModel * );
signals:
  void goToPreviousPage();
  void goToNextPage();
  /// includes the bool variable which is necessary for enable/disable the nextbutton of the keypage (which is found in opengpiwizard)
  void invalidKeysChangedKeyPage( bool );
private:
  QTreeView *treeView;
  TreeModel *treeModel;
  ListModel *listModel;
  QScrollArea *scrollArea;
  QWidget *widget;
  QHBoxLayout *hLayout;   /**< lines up widgets horizontally, treeView, rLayout */
  QVBoxLayout *rLayout;   /**< lines up widgets vertically, blockName, listView, infoBox.*/
  QLabel *infoBox;        /**< explains actual simulation parameter */
  QLabel *blockName;      /**< application name */
private slots:
  void replaceList( const QItemSelection &selection );
  void setBlockHidden( const QModelIndex & );
};

#endif
