/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "listmodel.h"

ListModel::ListModel( DataModel *model, QModelIndex index, QObject *object ) :
  QAbstractListModel( object ), dataModel( model ), parentIndex( index )
{
  connect( dataModel, SIGNAL( dataChanged( QModelIndex, QModelIndex ) ),
           this, SLOT( sendDataChanged( const QModelIndex & ) ) );
}

QModelIndex ListModel::dataIndex( const QModelIndex &listIndex ) const
{
  return dataModel->createIndex( parentIndex.row(), listIndex.row() + 4,
                                 parentIndex.internalPointer() );
}

QModelIndex ListModel::listIndex( const QModelIndex &dataIndex ) const
{
  return createIndex( dataIndex.column() - 4, 0, dataIndex.internalPointer() );
}

int ListModel::rowCount( const QModelIndex &parent ) const
{
  if ( !parent.isValid() ) {
    return static_cast<TreeItem *>( parentIndex.internalPointer() )
           ->columnCount() - 4;
  } else {
    return 0;
  }
}

QVariant ListModel::data( const QModelIndex &index, int role ) const
{
  if ( index.isValid() ) {
    TreeItem *item = static_cast<TreeItem *>( parentIndex.internalPointer() );
    QMap<QString, QVariant> map = item->data( dataIndex( index ).column() ).toMap();

    if ( role == Qt::DisplayRole ) {
      QString ret =
        map["displayname"].toString() + ":\n           " +
        map["value"].toString();
      return ret;
    }

    if ( role == Qt::EditRole ) {
      return map;
    }

    if ( role == Qt::BackgroundRole ) {
      if ( !dataModel->isDataValid( dataIndex( index ) ) ) {
        return QColor( Qt::red );
      }
    }
  }

  return QVariant();
}

void ListModel::setParent( QModelIndex index )
{
  parentIndex = index;
  emit layoutChanged();
}

Qt::ItemFlags ListModel::flags( const QModelIndex &index ) const
{
  if ( index.data( Qt::EditRole ).toMap()["enabled"].toBool() ) {
    return Qt::ItemIsEnabled | Qt::ItemIsEditable;
  } else {
    return Qt::NoItemFlags;
  }
}

bool ListModel::setData(
  const QModelIndex &index, const QVariant &value, int role )
{
  if ( !index.isValid() ) {
    return false;
  }

  if ( role == Qt::EditRole ) {
    qDebug() << "dIndex.row = " << dataIndex( index ).row()
             << ", dIndex.column = " << dataIndex( index ).column()
             << ", dIndex.intP = " << dataIndex( index ).internalPointer();
    return dataModel->setData( dataIndex( index ), value, Qt::EditRole );
  }

  return false;
}

void ListModel::sendDataChanged( const QModelIndex &index )
{
  if ( index.column() > 3 ) {
    QModelIndex lIndex = listIndex( index );
    qDebug() << "emit dataChanged(" << lIndex.row() << ", " <<
             lIndex.column() << ", " << lIndex.internalPointer();
    emit dataChanged( lIndex, lIndex );
  }
}
