/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka, Nikita Bogutzki
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "loadpage.h"
#include "xmlparamimport.h"

LoadPage::LoadPage( QWidget *parent )
  : QWizardPage( parent )
{
  setTitle( "Parameter Description File" );
  setSubTitle( "Specify the directory of the parameter description file." );
  text1 = new QLabel( "Click Browse button to select a parameter description file." );
  line = new QLineEdit();
  line->resize( 200, 30 );
  button = new QPushButton( "Browse..." );
  button->resize( 50, 30 );
  text2 = new QLabel( "Click \"Next\" to load the parameter description file." );
  hLayout = new QHBoxLayout();
  hLayout->addSpacing( 400 );
  rLayout = new QGridLayout();
  rLayout->addWidget( text1, 0, 0, 1, 2 );
  rLayout->addWidget( line, 1, 0, 1, 1 );
  rLayout->addWidget( button, 1, 1, 1, 1 );
  rLayout->addWidget( text2, 2, 0, 1, 2 );
  hLayout->addLayout( rLayout );
  setLayout( hLayout );
  connect( button, SIGNAL( clicked() ), this, SLOT( getInFileName() ) );
  connect( line, SIGNAL( textChanged( QString ) ), this, SLOT( checkDescriptionFileName() ) );

}

LoadPage::~LoadPage() {}

QString LoadPage::currentText()
{
  return line->text();
}

bool LoadPage::isComplete()const
{
  if ( line->text() == "" )
  {
    return false;
  }
  else {
    return true;
  }
}

void LoadPage::setText( QString text )
{
  line->setText( text );
}

void LoadPage::getInFileName()
{
  XMLParamImport::setCurrentDirectory();
  QFileDialog openDialog( this, tr( "Load Parameter Description" ), "./", tr( "Description Files (description_*.xml)" ) );
  openDialog.setFileMode( QFileDialog::ExistingFile );
  openDialog.setViewMode( QFileDialog::Detail );

  if ( openDialog.exec() ) {
    line->setText( openDialog.selectedFiles().at( 0 ) );
  }
}

void LoadPage::checkDescriptionFileName()
{
  QString s = line->text();
  bool ok;
  emit descriptionFileNameChanged( s, ok ); // returns variable "ok"
  emit descriptionFileNameIsOK( ok );
}
