/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


/**
 * The LoadPage is used to get the file name and directory of description
 * files or saved parameter files to be loaded. It presents a text line and a
 * browse button. The user can type the file name into the text line or use the
 * button to browse through the directories. The directory and file name in the
 * text line are automatically checked for existence.
 */


#ifndef LOADPAGE_H
#define LOADPAGE_H

#include <QtWidgets>

class LoadPage : public QWizardPage {
  Q_OBJECT

public:

  /**
   * Constructs a LoadPage with text line and browse button.
   * \param parent The parent widget.
   */
  LoadPage( QWidget *parent );

  /**
   * The destructor.
   */
  ~LoadPage();

  QString currentText(); /**< Returns the current text of the text line.*/
  void setText( QString text ); /**< Sets the text in the text line.*/
  bool isComplete()const;


public slots:
  /**
   * Uses the slot XMLParamImport::checkDescriptionFileName(QString,bool &) in
   * order to validate the text in the text line.
   * If the text is representing a valid directory, the signal
   * descriptionFileNameIsOK(true) is emitted, otherwise
   * descriptionFileNameIsOK(false) is emitted.
   */
  void checkDescriptionFileName();

signals:
  /**
   * Uses finally the slot XMLParamImport::checkDescriptionFileName(QString,bool &)
   * Through signales:
   * OpenGPIWizard::descriptionFileNameChanged()
   * OpenGPIGUI::descriptionFileNameChanged()
   * OpenPGI::descriptionFileNameChanged()
   * This signal is emitted, by slot checkDescriptionFileName().
   */
  void descriptionFileNameChanged( QString, bool & );
  /** This signal is emitted, if the directory and file name in the text line exist.
   *  Enables the "next" button.
   */
  void descriptionFileNameIsOK( bool );

private:

  QLabel *text1, *text2;
  QLineEdit *line; /**< Holds the path to the .xml file. */
  QPushButton *button; /**< Klick on this button emits signal to the slot getInFileName(). */
  QHBoxLayout *hLayout;
  QGridLayout *rLayout;

private slots:
  void getInFileName(); /**< This slot opens folder menu for chosing .xml files. */
};

#endif
