/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "opengpi.h"

#include <iostream>

OpenGPI::OpenGPI()
  : QWidget()
{
  Gui = new OpenGPIGUI( this, 0 );
  Data = new ParamData( this );
  Export = new XMLParamExport( this );
  Import = new XMLParamImport( this );
  connect( Gui, SIGNAL( descriptionFileNameChanged( QString, bool & ) ), Import,
           SLOT( checkDescriptionFileName( QString, bool & ) ) );
  connect( Gui, SIGNAL( sendDescriptionFileName( QString ) ), Import,
           SLOT( importDescription( QString ) ) );
  connect( Import, SIGNAL( sendDescriptionDoc( QDomDocument ) ), Data,
           SLOT( receiveDescriptionDoc( QDomDocument ) ) );
  connect( Gui, SIGNAL( paramFileNameLoadChanged( QString, bool& ) ), Import,
           SLOT( checkParamFileNameLoad( QString, bool& ) ) );
  connect( Gui, SIGNAL( sendParamFileName( QString ) ), Import,
           SLOT( importParam( QString ) ) );
  connect( Import, SIGNAL( sendParamDoc( QDomDocument ) ), Data,
           SLOT( receiveParamDoc( QDomDocument ) ) );
  connect( Data, SIGNAL( sendModel( QAbstractItemModel* ) ), Gui,
           SLOT( receiveModel( QAbstractItemModel* ) ) );
  connect( Gui, SIGNAL( checkAllBlocks() ), Data, SIGNAL( checkAllBlocks() ) );
  connect( Gui, SIGNAL( getFirstKeys() ), Data, SLOT( collectFirstKeys() ) );
  connect( Gui, SIGNAL( getNextKeys( QModelIndex ) ), Data, SLOT( collectNextKeys( QModelIndex ) ) );
  connect( Gui, SIGNAL( getPreviousKeys( QModelIndex ) ), Data,
           SLOT( collectPreviousKeys( QModelIndex ) ) );
  connect( Gui, SIGNAL( getKeys( QModelIndex ) ), Data, SLOT( collectKeys( QModelIndex ) ) );
  connect( Gui, SIGNAL( valueChanged( QVariant, QModelIndex ) ), Data,
           SLOT( changeValue( QVariant, QModelIndex ) ) );
  connect( Gui, SIGNAL( paramFileNameSaveChanged( QString, bool& ) ), Import,
           SLOT( checkParamFileNameSave( QString, bool& ) ) );
  connect( Gui, SIGNAL( executableFileNameChanged( QString, bool& ) ), Export,
           SLOT( checkExecutableFileName( QString, bool& ) ) );
  connect( Gui, SIGNAL( sendOutFileName( QString ) ), Data, SLOT( prepareExport( QString ) ) );
  connect( Data, SIGNAL( sendExportData( QDomDocument, QString ) ), Export,
           SLOT( exportData( QDomDocument, QString ) ) );
  connect( Gui, SIGNAL( getCurrentSettings() ), Data, SLOT( getCurrentSettings() ) );
  connect( Data, SIGNAL( sendCurrentSettings( QTreeWidgetItem* ) ), Gui,
           SIGNAL( sendCurrentSettings( QTreeWidgetItem* ) ) );
  connect( Data, SIGNAL( showInfo( QString ) ), Gui, SIGNAL( showInfo( QString ) ) );
  connect( Data, SIGNAL( keyInputOk( bool ) ), Gui, SLOT( receiveInputValidity( bool ) ) );

  if ( qApp->arguments().size() > 1 ) {
    QString descriptionFileName = qApp->arguments().at( 1 );
    bool fileNameOk;
    Import->checkDescriptionFileName( descriptionFileName, fileNameOk );

    if ( fileNameOk ) {
      Gui->setDescriptionFileName( QFileInfo( descriptionFileName ).absoluteFilePath() );
    } else {
      std::cout << "\"" << descriptionFileName.toStdString() << "\" is not a valid description file name." << std::endl;
      std::cout << "Description file name must be of the form: \"description_*.xml\"." << std::endl;
      deleteLater();
    }
  }
}

OpenGPI::~OpenGPI() {}

void OpenGPI::showGUI()
{
  Gui->show();
}
