/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


/**
 * OpenGPI contains the four modules of OpenGPI: The OpenGPIGUI, the ParamData, the XMLParamImport and the XMLParamExport.
 * It connects the signals and slots of the modules they are using to communicate with each other.
 */


#ifndef OPENGPI_H
#define OPENGPI_H

#include <QtWidgets>

#include "opengpigui.h"
#include "paramdata.h"
#include "xmlparamexport.h"
#include "xmlparamimport.h"


class OpenGPI: public QWidget {
  Q_OBJECT

public:

  /**
   * Constructs the modules and connects their signals and slots.
   */
  OpenGPI();

  /**
   * The destructor.
   */
  ~OpenGPI();

  void showGUI(); /**< Makes the OpenGPIGUI visible.*/

private:

  OpenGPIGUI *Gui;
  ParamData *Data;
  XMLParamExport *Export;
  XMLParamImport *Import;
};

#endif
