/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "opengpitree.h"
#include <QItemSelectionModel>

OpenGPITree::OpenGPITree( QWidget *parent )
  : QTreeView( parent )
{
  setSelectionBehavior( QAbstractItemView::SelectRows );
}

void OpenGPITree::setProperties()
{
  showColumn( 0 );
  setColumnWidth( 0, 280 );
  showColumn( 1 );
  setColumnWidth( 1, 35 );
  expandAll();
  connect( model(), SIGNAL( blockChanged( QModelIndex ) ), this,
           SLOT( updateBlock( QModelIndex ) ) );
  emit checkAllBlocks();
}

void OpenGPITree::updateBlock( QModelIndex i )
{
  setRowHidden( i.row(), i.parent(), !model()->data( i ).toBool() );
}

void OpenGPITree::guidedMode()
{
  setSelectionMode( QAbstractItemView::NoSelection );
}

void OpenGPITree::expertMode()
{
  setSelectionMode( QAbstractItemView::SingleSelection );
}

void OpenGPITree::selectIndex( QList<QModelIndex> index )
{
  if ( index.isEmpty() ) {
    clearSelection();
  } else {
    QItemSelectionModel *sm = this->selectionModel();
    QItemSelection selection( index[0], index[0] );
    sm->select( selection, QItemSelectionModel::ClearAndSelect );
  }
}
