/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/



#ifndef PARAMDATA_H
#define PARAMDATA_H

#include <QtWidgets>
#include "datamodel.h"

/**
 * ParamData is one of the main modules of OpenGPI. In it, the configuration data
 * is stored in the TreeModel class
 */
class ParamData : public QWidget {
private:
  Q_OBJECT
  DataModel* Model;


public:
  /**
   * Constructs the Model and connects the signals for communicating with it
   * \param parent: The parent widget
   */
  ParamData( QWidget *parent );
  /**
   * Destructor
   */
  ~ParamData();


signals:
  void sendModel( QAbstractItemModel* model );
  void sendNextKeys( QList<QVariant> data, QList<QModelIndex> index );
  void sendPreviousKeys( QList<QVariant> data, QList<QModelIndex> index );
  /**
   * Send the keys of the newly selected block
   * \param data: the keys
   * \param index: the selected block
   */
  void sendKeys( QList<QVariant> data, QList<QModelIndex> index );
  void sendExportData( QDomDocument, QString );
  void sendLoadDocData( QDomDocument, QString );
  void sendSummaryData( QDomDocument, QString );

  //  void dataChanged(QModelIndex,QVariant);

  void checkAllBlocks();

  void showInfo( QString );
  void sendCurrentSettings( QTreeWidgetItem* );
  void keyInputOk( bool );


public slots:

  /**
   * Receive the new description InDoc and delete all current data in the
   * model to make it ready for the new description
   * \param InDoc: description of the new configuration
   */
  void receiveDescriptionDoc( QDomDocument InDoc );
  /**
   * Receive the parameters, e.g. on load
   * \param doc: document containing the parameters
   */
  void receiveParamDoc( QDomDocument doc );
  void modelSetupFinished(); /**< Notify gui that model setup has finished*/
  void collectFirstKeys(); /**< Collect keys in the first hierarchy level*/
  /**
   * Collect the keys beneath the next enabled index following i
   * \param i: index of the current item
   */
  void collectNextKeys( QModelIndex i );
  /**
   * Collect the keys beneath the last enabled index before i
   * \param i: index of the current item
   */
  void collectPreviousKeys( QModelIndex i );
  /**
   * Get the current data for index
   * \param index: index of the current item
   */
  void collectKeys( QModelIndex index );
  /**
   * Change the value of the item at index
   * \param v: The new value
   * \param index: index of the item to update
   */
  void changeValue( QVariant v, QModelIndex index );
  /**
   * Get the data of an updated item
   * \param i: index of the item
   */
  void getKeyDataUpdate( QModelIndex i );
  /**
   * send the data to the exporter
   * \param outfilename: filename of the export
   */
  void prepareExport( QString outfilename );
  /**
   * send the complete current settings to the wizard
   */
  void getCurrentSettings();
};

#endif
