/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka, Nikita Bogutzki
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/



#ifndef RUNPAGE_H
#define RUNPAGE_H

#include <QtWidgets>
#include <QtTest>


/** The RunPage includes a textline for executing commands and a textbox for showing results. It allows the user to communicate with the terminal, where OpenGPI is running.
 */
class RunPage : public QWizardPage {
  Q_OBJECT
public:

  /**
   * Constructs a RunPage.
   */
  RunPage( QWidget *parent );

  /**
   * The destructor.
   */
  ~RunPage();

  QProcess *process;

public slots:

  /** Starts given executable. The buttons "Start" and "Stop" are switched from enabled to disabled or other way around.
   *
   */
  void startExecutableFile();
  /** Checks the text in the text line using the slot XMLParamExport::checkExecutableFileName(QString,bool &).
   *  If it represents a valid directory, the signal outFileNameIsOK(true) is emitted,
   *  otherwise the signal outFileNameIsOK(false) is emitted.
   */
  void checkExecutableFileName();
  /**
  * Starts make-command assiciated with the choosen Makefile
  */
  void startMakeFile();
  /**
   * Is called if text in line1 has been changed. Checks if choosen Makefile is valid; button2 will be enabled if absolute file path in line1 exists and file name is "Makefile"
   */
  void checkMakeFileName();
  /**
  * Is called if text in line2 has been changed. Checks if choosen picture file is valid; button5 will be enabled if absolute file path in line2 exists
  */
  void checkPictureFileName();

  /** Starts given simulation files.
   *
   */
  void startPictureFile();

  /** Stops running simulation.
   *
   */
  void stopPictureFile();

signals:
  /** This signal is emitted whenever the text in the text line changes (by user or by program).
   *  It passes true, if the text represents a valid file name, otherwise it passes false.
   */
  void executableFileNameIsOK( bool );
private:

  /** Counts the number of Executables which has been started since the beginning of the session.
   */
  QVariant *countExecutables;

  QGroupBox *groupBox;
  QRadioButton *radio1, *radio2, *radio3;
  QLabel *subtitle1, *subtitle2, *subtitle3;
  QLineEdit *line1, *line2;
  QTextEdit *outputText;
  QPushButton *button1, *button2, *button3, *button4, *button5, *button6, *button7;
  QHBoxLayout *hLayout1, *hLayout2, *hLayout3;
  QVBoxLayout *simBox, *vLayout;
  QGridLayout *gridLayout1, *gridLayout2;
  QLabel *imageLabel;
  QScrollArea *scrollArea;
  bool simulationBreak;

private slots:

  /** Opens new window for browsing towards the executable needed.
   */
  void getExecutableFileName();
  /** Opens new window for browsing towards the picte file needed.
   */
  void getPictureFileName();
};

#endif 
