/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/

#include <QStringList>
#include "treeitem.h"

TreeItem::TreeItem( const QList<QVariant> &data, TreeItem *parent )
{
  parentItem = parent;
  itemData = data;
}

TreeItem::~TreeItem()
{
  qDeleteAll( childItems );
}

void TreeItem::appendChild( TreeItem *item )
{
  childItems.append( item );
}

TreeItem *TreeItem::child( int row )
{
  return childItems.value( row );
}

int TreeItem::childCount() const
{
  return childItems.count();
}

int TreeItem::columnCount() const
{
  return itemData.count();
}

QVariant TreeItem::data( int column ) const
{
  return itemData.value( column );
}

TreeItem *TreeItem::parent()
{
  return parentItem;
}

int TreeItem::row() const
{
  if ( parentItem ) {
    return parentItem->childItems.indexOf( const_cast<TreeItem*>( this ) );
  }

  return 0;
}

int TreeItem::rowCount()
{
  if ( parentItem ) {
    return parentItem->childCount();
  }

  return 0;
}

void TreeItem::changeData( int index, QVariant value )
{
  itemData[index] = value;
}

void TreeItem::appendKey( QMap<QString, QVariant> &key )
{
  itemData.append( key );
}

void TreeItem::removeLastColumn()
{
  itemData.removeLast();
}
