/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TREEITEM_H
#define TREEITEM_H

#include <QList>
#include <QVariant>
#include <QSet>
#include <QModelIndex>

class DataModel;

class TreeModel;

/** The TreeItem class is used for storing the actual configuration data and is a node in the TreeModel class.
 */
class TreeItem {
private:
  friend class DataModel;
  friend class TreeModel;
  friend class ListModel;

  void appendChild( TreeItem *child );

  TreeItem *child( int row );
  int childCount() const;
  int columnCount() const;
  QVariant data( int column ) const;
  int row() const; /**< to obtain the item's row number */
  int rowCount();
  TreeItem *parent(); /**< to obtain the parent item */

  void changeData( int index, QVariant value );
  void appendKey( QMap<QString, QVariant> &key ); /**< used to add data when the model is first constructed and is not used during normal use */
  void removeLastColumn();

  QList<TreeItem*> childItems;
  QList<QVariant> itemData;
  TreeItem *parentItem;

  QSet<QModelIndex> invalidElementIndices;


public:
  /**
   * Initializes the parent and itemdata.
   */
  TreeItem( const QList<QVariant> &data, TreeItem *parent = 0 );

  /**
   * Destructor: Cleans up the childItems.
   */
  ~TreeItem();

};

#endif
