/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TREEMODEL_H
#define TREEMODEL_H

#include <QAbstractItemModel>
#include "datamodel.h"

/** TreeModel is part of the MVC using the QT MVC infrastructure.
 * It uses the TreeItem class for storage and stores the hierachical structure
 * of the configuration data.
 *
 */
class TreeModel : public QAbstractItemModel {
  Q_OBJECT
public:
  explicit TreeModel( DataModel *model, QObject *parent = 0 );
  // read only methods
  QModelIndex index( int row, int column, const QModelIndex &parent ) const;
  QModelIndex parent( const QModelIndex &child ) const;
  QVariant data( const QModelIndex &index, int role ) const;
  int rowCount( const QModelIndex &parent ) const;
  int columnCount( const QModelIndex &parent ) const;
  QVariant headerData( int section, Qt::Orientation orientation, int role ) const;
  QModelIndex treeIndex( const QModelIndex &dataIndex ) const;
  QModelIndex firstEnabledIndex() const;
  QModelIndex nextEnabledIndex( const QModelIndex &currentIndex ) const;
  QModelIndex previousEnabledIndex( const QModelIndex &currentIndex ) const;
  void start();
  void selectNext();
  void selectPrevious();

signals:
  void selectionChanged( QItemSelection );
  void afterLastIndex();
  void beforeFirstIndex();

public slots:
  void select( const QItemSelection & );

private:
  DataModel *dataModel;
  QItemSelection selected;

private slots:
  void sendDataChanged( const QModelIndex &index );

};

#endif 
