/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


from lxml import etree
import getopt
import sys

def main(argv=None):
    # parse command line options
    if argv is None:
        argv = sys.argv

    try: 
        opts, args = getopt.getopt(argv[1:], "h", ["help"])
    except getopt.error, msg:
        print msg
        print "for help use --help"
        return 2

    for o, a in opts:
        if o in ("-h", "--help"):
            print __doc__
            return 0
    
    try:
        schemafile = open(args[0])
    except IOError:
        print "Could not open file"
        return 1

    try:
        xmlfile = open(args[1])
    except IOError:
        print "Could not open XML file"
        schemafile.close()
        return 1

    xmlschema_doc = etree.parse(schemafile)
    schemafile.close()
    try:
        xmlschema = etree.XMLSchema(xmlschema_doc)
    except etree.XMLSchemaParseError, e:
        print "The XSD file is not valid"
        print e.error_log.last_error
        return 1

    doc = etree.parse(xmlfile)
    xmlfile.close()

    if xmlschema.validate(doc):
        print "XML file is valid."
        return 0
    
    log = xmlschema.error_log
    error = log.last_error
    print error.domain_name
    print error.type_name
    print error


if __name__ == "__main__":
    sys.exit(main())

