/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "xmlparamexport.h"

XMLParamExport::XMLParamExport( QWidget *parent )
  : QWidget( parent )
{
}

void XMLParamExport::initializeCurrentDirectory( const QString &path )
{
  if ( parameterFileName == 0 ) {
    parameterFileName = path;
  }
}

void XMLParamExport::setCurrentDirectory()
{
  QDir::setCurrent( QFileInfo( parameterFileName ).absoluteDir().absolutePath() );
}

void XMLParamExport::exportData( QDomDocument outdoc, QString outfilename )
{
  qDebug() << "outfilename: " << outfilename;
  parameterFileName = outfilename;
  QFile OutFile( outfilename, this );

  if ( OutFile.open( QIODevice::WriteOnly ) ) {
    OutFile.write( outdoc.toString( 2 ).toLatin1() );
  }

  OutFile.close();
}

QString XMLParamExport::parameterFileName = 0;

void XMLParamExport::checkExecutableFileName( QString filename, bool &ok )
{
  ok = QFileInfo( filename ).exists();
}

void XMLParamExport::runExternApplication( QString executable )
{
  qDebug() << "executable: " << executable;
  executableFileName = executable;
  QStringList parameters;
  parameters << parameterFileName;
  QProcess *process = new QProcess( this );
  process->start( executable, parameters );
}
