/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#include "xmlparamimport.h"
#include "xmlparamexport.h"

XMLParamImport::XMLParamImport( QWidget *parent )
  : QWidget( parent )
{
}

void XMLParamImport::checkDescriptionFileName( QString infilename, bool &ok )
{
  if ( QDir().exists( infilename ) ) {
    infilename = QFileInfo( infilename ).fileName();

    if ( infilename.startsWith( "description_" ) && infilename.endsWith( ".xml" ) ) {
      ok = true;
      QDir::setCurrent( QFileInfo( infilename ).absoluteDir().absolutePath() );
    } else {
      ok = false;
    }
  } else {
    ok = false;
  }
}

void XMLParamImport::importDescription( QString infilename )
{
  changeCurrentDirectory( infilename );
  QFile InFile;
  QDomDocument InDoc;
  InFile.setFileName( infilename );

  if ( InFile.open( QIODevice::ReadOnly ) ) {
    InDoc.setContent( &InFile );
  }

  InFile.close();
  emit sendDescriptionDoc( InDoc );
}

void XMLParamImport::checkParamFileNameLoad( QString filename, bool &ok )
{
  if ( QFileInfo( filename ).exists() ) {
    ok = hasParamFileName( filename );
  } else {
    ok = false;
  }
}

void XMLParamImport::checkParamFileNameSave( QString filename, bool &ok )
{
  if ( QFileInfo( filename ).absoluteDir().exists() ) {
    ok = hasParamFileName( filename );
  } else {
    ok = false;
  }
}

bool XMLParamImport::hasParamFileName( QString filename )
{
  filename = QFileInfo( filename ).fileName();

  if ( ( !filename.startsWith( "description_" ) ) && filename.endsWith( ".xml" ) ) {
    return true;
  } else {
    return false;
  }
}

void XMLParamImport::importParam( QString filename )
{
  //setCurrentDirectory(filename);
  changeCurrentDirectory( filename );
  QFile InFile;
  QDomDocument InDoc;
  InFile.setFileName( filename );

  if ( InFile.open( QIODevice::ReadOnly ) ) {
    InDoc.setContent( &InFile );
  }

  InFile.close();
  emit sendParamDoc( InDoc );
}

void XMLParamImport::setCurrentDirectory()
{
  QDir::setCurrent( QFileInfo( current_directory ).absoluteDir().absolutePath() );
}

QString XMLParamImport::current_directory = QDir::currentPath();

void XMLParamImport::changeCurrentDirectory( const QString &path )
{
  current_directory = path;
  XMLParamExport::initializeCurrentDirectory( path );
}
