/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  E-mail contact: info@opengpi.net
 *  The most recent release of OpenGPI can be downloaded at
 *  <http://www.opengpi.org/>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see <http://www.gnu.org/licenses/>.
*/


#ifndef XMLPARAMIMPORT_H
#define XMLPARAMIMPORT_H

#include <QtWidgets>
#include <QtXml>

/** XMLParamImport is used for importing the choosen XML file as a QDomDocument. It checks the existens and the name of the the XML-File.
*/
class XMLParamImport: public QWidget {
  Q_OBJECT

public:
  /**
   * Construct the XMLParamImport
   * \param parent: parent widget
   */
  XMLParamImport( QWidget *parent );
  static void setCurrentDirectory();

signals:

  void sendDescriptionDoc( QDomDocument );
  void sendParamDoc( QDomDocument );

public slots:
  /**
    * Checks description file name entered by user for validity
    * \param infilename: File name to be checked
    */
  void checkDescriptionFileName( QString infilename, bool &ok );
  /**
   * Import the description of the XML format used
   * \param infilename: the filename of the description file
   */
  void importDescription( QString infilename );
  /**
   * Checks parameter file name entered by user in order to load
   * parameter file for validity
   * \param filename: File name to be checked
   */
  void checkParamFileNameLoad( QString filename, bool &ok );
  /**
   * Checks parameter file name entered by user in order to save
   * parameter file for validity
   * \param filename: File name to be checked
   */
  void checkParamFileNameSave( QString filename, bool &ok );
  /**
   * Import the parameters
   * \param filename: The file name of the XML file with the params
   */
  void importParam( QString filename );

private:
  bool hasParamFileName( QString filename );
  void changeCurrentDirectory( const QString &path );

  static QString current_directory;
};


#endif
